"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PositronDataSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PositronDataSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PositronDataSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MESSAGES: _PositronDataSource.ValueType  # 1
    CHATS: _PositronDataSource.ValueType  # 2
    CONTACTS: _PositronDataSource.ValueType  # 3
    GROUP_METADATA: _PositronDataSource.ValueType  # 4
    GROUP_PARTICIPANTS: _PositronDataSource.ValueType  # 5
    REACTIONS: _PositronDataSource.ValueType  # 6

class PositronDataSource(_PositronDataSource, metaclass=_PositronDataSourceEnumTypeWrapper): ...

MESSAGES: PositronDataSource.ValueType  # 1
CHATS: PositronDataSource.ValueType  # 2
CONTACTS: PositronDataSource.ValueType  # 3
GROUP_METADATA: PositronDataSource.ValueType  # 4
GROUP_PARTICIPANTS: PositronDataSource.ValueType  # 5
REACTIONS: PositronDataSource.ValueType  # 6
global___PositronDataSource = PositronDataSource

@typing.final
class PositronMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MsgKey(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FROMME_FIELD_NUMBER: builtins.int
        REMOTE_FIELD_NUMBER: builtins.int
        ID_FIELD_NUMBER: builtins.int
        PARTICIPANT_FIELD_NUMBER: builtins.int
        fromMe: builtins.bool
        ID: builtins.str
        @property
        def remote(self) -> global___PositronMessage.WID: ...
        @property
        def participant(self) -> global___PositronMessage.WID: ...
        def __init__(
            self,
            *,
            fromMe: builtins.bool | None = ...,
            remote: global___PositronMessage.WID | None = ...,
            ID: builtins.str | None = ...,
            participant: global___PositronMessage.WID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ID", b"ID", "fromMe", b"fromMe", "participant", b"participant", "remote", b"remote"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ID", b"ID", "fromMe", b"fromMe", "participant", b"participant", "remote", b"remote"]) -> None: ...

    @typing.final
    class WID(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERIALIZED_FIELD_NUMBER: builtins.int
        serialized: builtins.str
        def __init__(
            self,
            *,
            serialized: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["serialized", b"serialized"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["serialized", b"serialized"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    type: builtins.str
    body: builtins.str
    JSON: builtins.str
    @property
    def ID(self) -> global___PositronMessage.MsgKey: ...
    def __init__(
        self,
        *,
        timestamp: builtins.int | None = ...,
        type: builtins.str | None = ...,
        body: builtins.str | None = ...,
        ID: global___PositronMessage.MsgKey | None = ...,
        JSON: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "body", b"body", "timestamp", b"timestamp", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "body", b"body", "timestamp", b"timestamp", "type", b"type"]) -> None: ...

global___PositronMessage = PositronMessage

@typing.final
class PositronChat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    UNREADCOUNT_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    ID: builtins.str
    name: builtins.str
    timestamp: builtins.int
    unreadCount: builtins.int
    JSON: builtins.str
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        name: builtins.str | None = ...,
        timestamp: builtins.int | None = ...,
        unreadCount: builtins.int | None = ...,
        JSON: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "name", b"name", "timestamp", b"timestamp", "unreadCount", b"unreadCount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "name", b"name", "timestamp", b"timestamp", "unreadCount", b"unreadCount"]) -> None: ...

global___PositronChat = PositronChat

@typing.final
class PositronContact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PHONENUMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ISADDRESSBOOKCONTACT_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    ID: builtins.str
    phoneNumber: builtins.str
    name: builtins.str
    isAddressBookContact: builtins.bool
    JSON: builtins.str
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        phoneNumber: builtins.str | None = ...,
        name: builtins.str | None = ...,
        isAddressBookContact: builtins.bool | None = ...,
        JSON: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "isAddressBookContact", b"isAddressBookContact", "name", b"name", "phoneNumber", b"phoneNumber"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "isAddressBookContact", b"isAddressBookContact", "name", b"name", "phoneNumber", b"phoneNumber"]) -> None: ...

global___PositronContact = PositronContact

@typing.final
class PositronGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    ID: builtins.str
    subject: builtins.str
    JSON: builtins.str
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        subject: builtins.str | None = ...,
        JSON: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "subject", b"subject"]) -> None: ...

global___PositronGroupMetadata = PositronGroupMetadata

@typing.final
class PositronGroupParticipants(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    ID: builtins.str
    JSON: builtins.str
    @property
    def participants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        participants: collections.abc.Iterable[builtins.str] | None = ...,
        JSON: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "participants", b"participants"]) -> None: ...

global___PositronGroupParticipants = PositronGroupParticipants

@typing.final
class PositronReaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PARENTMSGKEY_FIELD_NUMBER: builtins.int
    REACTIONTEXT_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    SENDERUSERJID_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    ID: builtins.str
    parentMsgKey: builtins.str
    reactionText: builtins.str
    timestamp: builtins.int
    senderUserJID: builtins.str
    JSON: builtins.str
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        parentMsgKey: builtins.str | None = ...,
        reactionText: builtins.str | None = ...,
        timestamp: builtins.int | None = ...,
        senderUserJID: builtins.str | None = ...,
        JSON: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "parentMsgKey", b"parentMsgKey", "reactionText", b"reactionText", "senderUserJID", b"senderUserJID", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "JSON", b"JSON", "parentMsgKey", b"parentMsgKey", "reactionText", b"reactionText", "senderUserJID", b"senderUserJID", "timestamp", b"timestamp"]) -> None: ...

global___PositronReaction = PositronReaction

@typing.final
class PositronData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASOURCE_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    CHATS_FIELD_NUMBER: builtins.int
    CONTACTS_FIELD_NUMBER: builtins.int
    GROUPMETADATA_FIELD_NUMBER: builtins.int
    GROUPPARTICIPANTS_FIELD_NUMBER: builtins.int
    REACTIONS_FIELD_NUMBER: builtins.int
    dataSource: global___PositronDataSource.ValueType
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PositronMessage]: ...
    @property
    def chats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PositronChat]: ...
    @property
    def contacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PositronContact]: ...
    @property
    def groupMetadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PositronGroupMetadata]: ...
    @property
    def groupParticipants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PositronGroupParticipants]: ...
    @property
    def reactions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PositronReaction]: ...
    def __init__(
        self,
        *,
        dataSource: global___PositronDataSource.ValueType | None = ...,
        messages: collections.abc.Iterable[global___PositronMessage] | None = ...,
        chats: collections.abc.Iterable[global___PositronChat] | None = ...,
        contacts: collections.abc.Iterable[global___PositronContact] | None = ...,
        groupMetadata: collections.abc.Iterable[global___PositronGroupMetadata] | None = ...,
        groupParticipants: collections.abc.Iterable[global___PositronGroupParticipants] | None = ...,
        reactions: collections.abc.Iterable[global___PositronReaction] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dataSource", b"dataSource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chats", b"chats", "contacts", b"contacts", "dataSource", b"dataSource", "groupMetadata", b"groupMetadata", "groupParticipants", b"groupParticipants", "messages", b"messages", "reactions", b"reactions"]) -> None: ...

global___PositronData = PositronData



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waHistorySync/WAWebProtobufsHistorySync.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waHistorySync/WAWebProtobufsHistorySync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waSyncAction import WASyncAction_pb2 as waSyncAction_dot_WASyncAction__pb2
from waChatLockSettings import WAProtobufsChatLockSettings_pb2 as waChatLockSettings_dot_WAProtobufsChatLockSettings__pb2
from waE2E import WAWebProtobufsE2E_pb2 as waE2E_dot_WAWebProtobufsE2E__pb2
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2
from waWeb import WAWebProtobufsWeb_pb2 as waWeb_dot_WAWebProtobufsWeb__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-waHistorySync/WAWebProtobufsHistorySync.proto\x12\x19WAWebProtobufsHistorySync\x1a\x1fwaSyncAction/WASyncAction.proto\x1a\x34waChatLockSettings/WAProtobufsChatLockSettings.proto\x1a\x1dwaE2E/WAWebProtobufsE2E.proto\x1a\x17waCommon/WACommon.proto\x1a\x1dwaWeb/WAWebProtobufsWeb.proto\"\xe2\x08\n\x0bHistorySync\x12H\n\x08syncType\x18\x01 \x02(\x0e\x32\x36.WAWebProtobufsHistorySync.HistorySync.HistorySyncType\x12>\n\rconversations\x18\x02 \x03(\x0b\x32\'.WAWebProtobufsHistorySync.Conversation\x12;\n\x10statusV3Messages\x18\x03 \x03(\x0b\x32!.WAWebProtobufsWeb.WebMessageInfo\x12\x12\n\nchunkOrder\x18\x05 \x01(\r\x12\x10\n\x08progress\x18\x06 \x01(\r\x12\x36\n\tpushnames\x18\x07 \x03(\x0b\x32#.WAWebProtobufsHistorySync.Pushname\x12\x41\n\x0eglobalSettings\x18\x08 \x01(\x0b\x32).WAWebProtobufsHistorySync.GlobalSettings\x12\x1a\n\x12threadIDUserSecret\x18\t \x01(\x0c\x12\x1f\n\x17threadDsTimeframeOffset\x18\n \x01(\r\x12\x42\n\x0erecentStickers\x18\x0b \x03(\x0b\x32*.WAWebProtobufsHistorySync.StickerMetadata\x12\x45\n\x10pastParticipants\x18\x0c \x03(\x0b\x32+.WAWebProtobufsHistorySync.PastParticipants\x12\x33\n\x0e\x63\x61llLogRecords\x18\r \x03(\x0b\x32\x1b.WASyncAction.CallLogRecord\x12R\n\x0f\x61iWaitListState\x18\x0e \x01(\x0e\x32\x39.WAWebProtobufsHistorySync.HistorySync.BotAIWaitListState\x12T\n\x18phoneNumberToLidMappings\x18\x0f \x03(\x0b\x32\x32.WAWebProtobufsHistorySync.PhoneNumberToLIDMapping\x12\x1a\n\x12\x63ompanionMetaNonce\x18\x10 \x01(\t\x12,\n$shareableChatIdentifierEncryptionKey\x18\x11 \x01(\x0c\x12\x34\n\x08\x61\x63\x63ounts\x18\x12 \x03(\x0b\x32\".WAWebProtobufsHistorySync.Account\"7\n\x12\x42otAIWaitListState\x12\x0f\n\x0bIN_WAITLIST\x10\x00\x12\x10\n\x0c\x41I_AVAILABLE\x10\x01\"\x8a\x01\n\x0fHistorySyncType\x12\x15\n\x11INITIAL_BOOTSTRAP\x10\x00\x12\x15\n\x11INITIAL_STATUS_V3\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x12\n\n\x06RECENT\x10\x03\x12\r\n\tPUSH_NAME\x10\x04\x12\x15\n\x11NON_BLOCKING_DATA\x10\x05\x12\r\n\tON_DEMAND\x10\x06\"\xf3\r\n\x0c\x43onversation\x12\n\n\x02ID\x18\x01 \x02(\t\x12;\n\x08messages\x18\x02 \x03(\x0b\x32).WAWebProtobufsHistorySync.HistorySyncMsg\x12\x0e\n\x06newJID\x18\x03 \x01(\t\x12\x0e\n\x06oldJID\x18\x04 \x01(\t\x12\x18\n\x10lastMsgTimestamp\x18\x05 \x01(\x04\x12\x13\n\x0bunreadCount\x18\x06 \x01(\r\x12\x10\n\x08readOnly\x18\x07 \x01(\x08\x12\x1c\n\x14\x65ndOfHistoryTransfer\x18\x08 \x01(\x08\x12\x1b\n\x13\x65phemeralExpiration\x18\t \x01(\r\x12!\n\x19\x65phemeralSettingTimestamp\x18\n \x01(\x03\x12\x62\n\x18\x65ndOfHistoryTransferType\x18\x0b \x01(\x0e\x32@.WAWebProtobufsHistorySync.Conversation.EndOfHistoryTransferType\x12\x1d\n\x15\x63onversationTimestamp\x18\x0c \x01(\x04\x12\x0c\n\x04name\x18\r \x01(\t\x12\r\n\x05pHash\x18\x0e \x01(\t\x12\x0f\n\x07notSpam\x18\x0f \x01(\x08\x12\x10\n\x08\x61rchived\x18\x10 \x01(\x08\x12=\n\x10\x64isappearingMode\x18\x11 \x01(\x0b\x32#.WAWebProtobufsE2E.DisappearingMode\x12\x1a\n\x12unreadMentionCount\x18\x12 \x01(\r\x12\x16\n\x0emarkedAsUnread\x18\x13 \x01(\x08\x12@\n\x0bparticipant\x18\x14 \x03(\x0b\x32+.WAWebProtobufsHistorySync.GroupParticipant\x12\x0f\n\x07tcToken\x18\x15 \x01(\x0c\x12\x18\n\x10tcTokenTimestamp\x18\x16 \x01(\x04\x12!\n\x19\x63ontactPrimaryIdentityKey\x18\x17 \x01(\x0c\x12\x0e\n\x06pinned\x18\x18 \x01(\r\x12\x13\n\x0bmuteEndTime\x18\x19 \x01(\x04\x12?\n\twallpaper\x18\x1a \x01(\x0b\x32,.WAWebProtobufsHistorySync.WallpaperSettings\x12\x43\n\x0fmediaVisibility\x18\x1b \x01(\x0e\x32*.WAWebProtobufsHistorySync.MediaVisibility\x12\x1e\n\x16tcTokenSenderTimestamp\x18\x1c \x01(\x04\x12\x11\n\tsuspended\x18\x1d \x01(\x08\x12\x12\n\nterminated\x18\x1e \x01(\x08\x12\x11\n\tcreatedAt\x18\x1f \x01(\x04\x12\x11\n\tcreatedBy\x18  \x01(\t\x12\x13\n\x0b\x64\x65scription\x18! \x01(\t\x12\x0f\n\x07support\x18\" \x01(\x08\x12\x15\n\risParentGroup\x18# \x01(\x08\x12\x15\n\rparentGroupID\x18% \x01(\t\x12\x19\n\x11isDefaultSubgroup\x18$ \x01(\x08\x12\x13\n\x0b\x64isplayName\x18& \x01(\t\x12\r\n\x05pnJID\x18\' \x01(\t\x12\x12\n\nshareOwnPn\x18( \x01(\x08\x12\x1d\n\x15pnhDuplicateLidThread\x18) \x01(\x08\x12\x0e\n\x06lidJID\x18* \x01(\t\x12\x10\n\x08username\x18+ \x01(\t\x12\x15\n\rlidOriginType\x18, \x01(\t\x12\x15\n\rcommentsCount\x18- \x01(\r\x12\x0e\n\x06locked\x18. \x01(\x08\x12N\n\x15systemMessageToInsert\x18/ \x01(\x0e\x32/.WAWebProtobufsHistorySync.PrivacySystemMessage\x12\x18\n\x10\x63\x61piCreatedGroup\x18\x30 \x01(\x08\x12\x12\n\naccountLid\x18\x31 \x01(\t\x12\x14\n\x0climitSharing\x18\x32 \x01(\x08\x12$\n\x1climitSharingSettingTimestamp\x18\x33 \x01(\x03\x12;\n\x13limitSharingTrigger\x18\x34 \x01(\x0e\x32\x1e.WACommon.LimitSharing.Trigger\x12!\n\x19limitSharingInitiatedByMe\x18\x35 \x01(\x08\"\xbc\x01\n\x18\x45ndOfHistoryTransferType\x12\x30\n,COMPLETE_BUT_MORE_MESSAGES_REMAIN_ON_PRIMARY\x10\x00\x12\x32\n.COMPLETE_AND_NO_MORE_MESSAGE_REMAIN_ON_PRIMARY\x10\x01\x12:\n6COMPLETE_ON_DEMAND_SYNC_BUT_MORE_MSG_REMAIN_ON_PRIMARY\x10\x02\"\x93\x01\n\x10GroupParticipant\x12\x0f\n\x07userJID\x18\x01 \x02(\t\x12>\n\x04rank\x18\x02 \x01(\x0e\x32\x30.WAWebProtobufsHistorySync.GroupParticipant.Rank\".\n\x04Rank\x12\x0b\n\x07REGULAR\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\x0e\n\nSUPERADMIN\x10\x02\"\xa6\x01\n\x0fPastParticipant\x12\x0f\n\x07userJID\x18\x01 \x01(\t\x12K\n\x0bleaveReason\x18\x02 \x01(\x0e\x32\x36.WAWebProtobufsHistorySync.PastParticipant.LeaveReason\x12\x0f\n\x07leaveTS\x18\x03 \x01(\x04\"$\n\x0bLeaveReason\x12\x08\n\x04LEFT\x10\x00\x12\x0b\n\x07REMOVED\x10\x01\"8\n\x17PhoneNumberToLIDMapping\x12\r\n\x05pnJID\x18\x01 \x01(\t\x12\x0e\n\x06lidJID\x18\x02 \x01(\t\"X\n\x07\x41\x63\x63ount\x12\x0b\n\x03lid\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x13\n\x0b\x63ountryCode\x18\x03 \x01(\t\x12\x19\n\x11isUsernameDeleted\x18\x04 \x01(\x08\"X\n\x0eHistorySyncMsg\x12\x32\n\x07message\x18\x01 \x01(\x0b\x32!.WAWebProtobufsWeb.WebMessageInfo\x12\x12\n\nmsgOrderID\x18\x02 \x01(\x04\"(\n\x08Pushname\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x10\n\x08pushname\x18\x02 \x01(\t\"6\n\x11WallpaperSettings\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0f\n\x07opacity\x18\x02 \x01(\r\"\xd1\x08\n\x0eGlobalSettings\x12I\n\x13lightThemeWallpaper\x18\x01 \x01(\x0b\x32,.WAWebProtobufsHistorySync.WallpaperSettings\x12\x43\n\x0fmediaVisibility\x18\x02 \x01(\x0e\x32*.WAWebProtobufsHistorySync.MediaVisibility\x12H\n\x12\x64\x61rkThemeWallpaper\x18\x03 \x01(\x0b\x32,.WAWebProtobufsHistorySync.WallpaperSettings\x12I\n\x10\x61utoDownloadWiFi\x18\x04 \x01(\x0b\x32/.WAWebProtobufsHistorySync.AutoDownloadSettings\x12M\n\x14\x61utoDownloadCellular\x18\x05 \x01(\x0b\x32/.WAWebProtobufsHistorySync.AutoDownloadSettings\x12L\n\x13\x61utoDownloadRoaming\x18\x06 \x01(\x0b\x32/.WAWebProtobufsHistorySync.AutoDownloadSettings\x12*\n\"showIndividualNotificationsPreview\x18\x07 \x01(\x08\x12%\n\x1dshowGroupNotificationsPreview\x18\x08 \x01(\x08\x12 \n\x18\x64isappearingModeDuration\x18\t \x01(\x05\x12!\n\x19\x64isappearingModeTimestamp\x18\n \x01(\x03\x12I\n\x12\x61vatarUserSettings\x18\x0b \x01(\x0b\x32-.WAWebProtobufsHistorySync.AvatarUserSettings\x12\x10\n\x08\x66ontSize\x18\x0c \x01(\x05\x12\x1d\n\x15securityNotifications\x18\r \x01(\x08\x12\x1a\n\x12\x61utoUnarchiveChats\x18\x0e \x01(\x08\x12\x18\n\x10videoQualityMode\x18\x0f \x01(\x05\x12\x18\n\x10photoQualityMode\x18\x10 \x01(\x05\x12W\n\x1eindividualNotificationSettings\x18\x11 \x01(\x0b\x32/.WAWebProtobufsHistorySync.NotificationSettings\x12R\n\x19groupNotificationSettings\x18\x12 \x01(\x0b\x32/.WAWebProtobufsHistorySync.NotificationSettings\x12G\n\x10\x63hatLockSettings\x18\x13 \x01(\x0b\x32-.WAProtobufsChatLockSettings.ChatLockSettings\x12#\n\x1b\x63hatDbLidMigrationTimestamp\x18\x14 \x01(\x03\"w\n\x14\x41utoDownloadSettings\x12\x16\n\x0e\x64ownloadImages\x18\x01 \x01(\x08\x12\x15\n\rdownloadAudio\x18\x02 \x01(\x08\x12\x15\n\rdownloadVideo\x18\x03 \x01(\x08\x12\x19\n\x11\x64ownloadDocuments\x18\x04 \x01(\x08\"\xf1\x01\n\x0fStickerMetadata\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x12\n\nfileSHA256\x18\x02 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x04 \x01(\x0c\x12\x10\n\x08mimetype\x18\x05 \x01(\t\x12\x0e\n\x06height\x18\x06 \x01(\r\x12\r\n\x05width\x18\x07 \x01(\r\x12\x12\n\ndirectPath\x18\x08 \x01(\t\x12\x12\n\nfileLength\x18\t \x01(\x04\x12\x0e\n\x06weight\x18\n \x01(\x02\x12\x19\n\x11lastStickerSentTS\x18\x0b \x01(\x03\x12\x10\n\x08isLottie\x18\x0c \x01(\x08\"j\n\x10PastParticipants\x12\x10\n\x08groupJID\x18\x01 \x01(\t\x12\x44\n\x10pastParticipants\x18\x02 \x03(\x0b\x32*.WAWebProtobufsHistorySync.PastParticipant\"4\n\x12\x41vatarUserSettings\x12\x0c\n\x04\x46\x42ID\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\xa9\x01\n\x14NotificationSettings\x12\x16\n\x0emessageVibrate\x18\x01 \x01(\t\x12\x14\n\x0cmessagePopup\x18\x02 \x01(\t\x12\x14\n\x0cmessageLight\x18\x03 \x01(\t\x12 \n\x18lowPriorityNotifications\x18\x04 \x01(\x08\x12\x16\n\x0ereactionsMuted\x18\x05 \x01(\x08\x12\x13\n\x0b\x63\x61llVibrate\x18\x06 \x01(\t*/\n\x0fMediaVisibility\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x06\n\x02ON\x10\x02*E\n\x14PrivacySystemMessage\x12\x0c\n\x08\x45\x32\x45\x45_MSG\x10\x01\x12\x0e\n\nNE2EE_SELF\x10\x02\x12\x0f\n\x0bNE2EE_OTHER\x10\x03\x42)Z\'go.mau.fi/whatsmeow/proto/waHistorySync')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waHistorySync.WAWebProtobufsHistorySync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waHistorySync'
  _globals['_MEDIAVISIBILITY']._serialized_start=5619
  _globals['_MEDIAVISIBILITY']._serialized_end=5666
  _globals['_PRIVACYSYSTEMMESSAGE']._serialized_start=5668
  _globals['_PRIVACYSYSTEMMESSAGE']._serialized_end=5737
  _globals['_HISTORYSYNC']._serialized_start=251
  _globals['_HISTORYSYNC']._serialized_end=1373
  _globals['_HISTORYSYNC_BOTAIWAITLISTSTATE']._serialized_start=1177
  _globals['_HISTORYSYNC_BOTAIWAITLISTSTATE']._serialized_end=1232
  _globals['_HISTORYSYNC_HISTORYSYNCTYPE']._serialized_start=1235
  _globals['_HISTORYSYNC_HISTORYSYNCTYPE']._serialized_end=1373
  _globals['_CONVERSATION']._serialized_start=1376
  _globals['_CONVERSATION']._serialized_end=3155
  _globals['_CONVERSATION_ENDOFHISTORYTRANSFERTYPE']._serialized_start=2967
  _globals['_CONVERSATION_ENDOFHISTORYTRANSFERTYPE']._serialized_end=3155
  _globals['_GROUPPARTICIPANT']._serialized_start=3158
  _globals['_GROUPPARTICIPANT']._serialized_end=3305
  _globals['_GROUPPARTICIPANT_RANK']._serialized_start=3259
  _globals['_GROUPPARTICIPANT_RANK']._serialized_end=3305
  _globals['_PASTPARTICIPANT']._serialized_start=3308
  _globals['_PASTPARTICIPANT']._serialized_end=3474
  _globals['_PASTPARTICIPANT_LEAVEREASON']._serialized_start=3438
  _globals['_PASTPARTICIPANT_LEAVEREASON']._serialized_end=3474
  _globals['_PHONENUMBERTOLIDMAPPING']._serialized_start=3476
  _globals['_PHONENUMBERTOLIDMAPPING']._serialized_end=3532
  _globals['_ACCOUNT']._serialized_start=3534
  _globals['_ACCOUNT']._serialized_end=3622
  _globals['_HISTORYSYNCMSG']._serialized_start=3624
  _globals['_HISTORYSYNCMSG']._serialized_end=3712
  _globals['_PUSHNAME']._serialized_start=3714
  _globals['_PUSHNAME']._serialized_end=3754
  _globals['_WALLPAPERSETTINGS']._serialized_start=3756
  _globals['_WALLPAPERSETTINGS']._serialized_end=3810
  _globals['_GLOBALSETTINGS']._serialized_start=3813
  _globals['_GLOBALSETTINGS']._serialized_end=4918
  _globals['_AUTODOWNLOADSETTINGS']._serialized_start=4920
  _globals['_AUTODOWNLOADSETTINGS']._serialized_end=5039
  _globals['_STICKERMETADATA']._serialized_start=5042
  _globals['_STICKERMETADATA']._serialized_end=5283
  _globals['_PASTPARTICIPANTS']._serialized_start=5285
  _globals['_PASTPARTICIPANTS']._serialized_end=5391
  _globals['_AVATARUSERSETTINGS']._serialized_start=5393
  _globals['_AVATARUSERSETTINGS']._serialized_end=5445
  _globals['_NOTIFICATIONSETTINGS']._serialized_start=5448
  _globals['_NOTIFICATIONSETTINGS']._serialized_end=5617
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MultiDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        @property
        def applicationData(self) -> global___MultiDevice.ApplicationData: ...
        @property
        def signal(self) -> global___MultiDevice.Signal: ...
        def __init__(
            self,
            *,
            applicationData: global___MultiDevice.ApplicationData | None = ...,
            signal: global___MultiDevice.Signal | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationData", b"applicationData", "payload", b"payload", "signal", b"signal"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationData", b"applicationData", "payload", b"payload", "signal", b"signal"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["applicationData", "signal"] | None: ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class AppStateSyncKeyRequestMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEYIDS_FIELD_NUMBER: builtins.int
            @property
            def keyIDs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiDevice.ApplicationData.AppStateSyncKeyId]: ...
            def __init__(
                self,
                *,
                keyIDs: collections.abc.Iterable[global___MultiDevice.ApplicationData.AppStateSyncKeyId] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["keyIDs", b"keyIDs"]) -> None: ...

        @typing.final
        class AppStateSyncKeyShareMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEYS_FIELD_NUMBER: builtins.int
            @property
            def keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiDevice.ApplicationData.AppStateSyncKey]: ...
            def __init__(
                self,
                *,
                keys: collections.abc.Iterable[global___MultiDevice.ApplicationData.AppStateSyncKey] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["keys", b"keys"]) -> None: ...

        @typing.final
        class AppStateSyncKey(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class AppStateSyncKeyData(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                @typing.final
                class AppStateSyncKeyFingerprint(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    RAWID_FIELD_NUMBER: builtins.int
                    CURRENTINDEX_FIELD_NUMBER: builtins.int
                    DEVICEINDEXES_FIELD_NUMBER: builtins.int
                    rawID: builtins.int
                    currentIndex: builtins.int
                    @property
                    def deviceIndexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
                    def __init__(
                        self,
                        *,
                        rawID: builtins.int | None = ...,
                        currentIndex: builtins.int | None = ...,
                        deviceIndexes: collections.abc.Iterable[builtins.int] | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["currentIndex", b"currentIndex", "rawID", b"rawID"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["currentIndex", b"currentIndex", "deviceIndexes", b"deviceIndexes", "rawID", b"rawID"]) -> None: ...

                KEYDATA_FIELD_NUMBER: builtins.int
                FINGERPRINT_FIELD_NUMBER: builtins.int
                TIMESTAMP_FIELD_NUMBER: builtins.int
                keyData: builtins.bytes
                timestamp: builtins.int
                @property
                def fingerprint(self) -> global___MultiDevice.ApplicationData.AppStateSyncKey.AppStateSyncKeyData.AppStateSyncKeyFingerprint: ...
                def __init__(
                    self,
                    *,
                    keyData: builtins.bytes | None = ...,
                    fingerprint: global___MultiDevice.ApplicationData.AppStateSyncKey.AppStateSyncKeyData.AppStateSyncKeyFingerprint | None = ...,
                    timestamp: builtins.int | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["fingerprint", b"fingerprint", "keyData", b"keyData", "timestamp", b"timestamp"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["fingerprint", b"fingerprint", "keyData", b"keyData", "timestamp", b"timestamp"]) -> None: ...

            KEYID_FIELD_NUMBER: builtins.int
            KEYDATA_FIELD_NUMBER: builtins.int
            @property
            def keyID(self) -> global___MultiDevice.ApplicationData.AppStateSyncKeyId: ...
            @property
            def keyData(self) -> global___MultiDevice.ApplicationData.AppStateSyncKey.AppStateSyncKeyData: ...
            def __init__(
                self,
                *,
                keyID: global___MultiDevice.ApplicationData.AppStateSyncKeyId | None = ...,
                keyData: global___MultiDevice.ApplicationData.AppStateSyncKey.AppStateSyncKeyData | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["keyData", b"keyData", "keyID", b"keyID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["keyData", b"keyData", "keyID", b"keyID"]) -> None: ...

        @typing.final
        class AppStateSyncKeyId(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEYID_FIELD_NUMBER: builtins.int
            keyID: builtins.bytes
            def __init__(
                self,
                *,
                keyID: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["keyID", b"keyID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["keyID", b"keyID"]) -> None: ...

        APPSTATESYNCKEYSHARE_FIELD_NUMBER: builtins.int
        APPSTATESYNCKEYREQUEST_FIELD_NUMBER: builtins.int
        @property
        def appStateSyncKeyShare(self) -> global___MultiDevice.ApplicationData.AppStateSyncKeyShareMessage: ...
        @property
        def appStateSyncKeyRequest(self) -> global___MultiDevice.ApplicationData.AppStateSyncKeyRequestMessage: ...
        def __init__(
            self,
            *,
            appStateSyncKeyShare: global___MultiDevice.ApplicationData.AppStateSyncKeyShareMessage | None = ...,
            appStateSyncKeyRequest: global___MultiDevice.ApplicationData.AppStateSyncKeyRequestMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["appStateSyncKeyRequest", b"appStateSyncKeyRequest", "appStateSyncKeyShare", b"appStateSyncKeyShare", "applicationData", b"applicationData"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["appStateSyncKeyRequest", b"appStateSyncKeyRequest", "appStateSyncKeyShare", b"appStateSyncKeyShare", "applicationData", b"applicationData"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["applicationData", b"applicationData"]) -> typing.Literal["appStateSyncKeyShare", "appStateSyncKeyRequest"] | None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___MultiDevice.Payload: ...
    @property
    def metadata(self) -> global___MultiDevice.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___MultiDevice.Payload | None = ...,
        metadata: global___MultiDevice.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> None: ...

global___MultiDevice = MultiDevice



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waMmsRetry/WAMmsRetry.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waMmsRetry/WAMmsRetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwaMmsRetry/WAMmsRetry.proto\x12\nWAMmsRetry\"\xe7\x01\n\x16MediaRetryNotification\x12\x10\n\x08stanzaID\x18\x01 \x01(\t\x12\x12\n\ndirectPath\x18\x02 \x01(\t\x12=\n\x06result\x18\x03 \x01(\x0e\x32-.WAMmsRetry.MediaRetryNotification.ResultType\x12\x15\n\rmessageSecret\x18\x04 \x01(\x0c\"Q\n\nResultType\x12\x11\n\rGENERAL_ERROR\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNOT_FOUND\x10\x02\x12\x14\n\x10\x44\x45\x43RYPTION_ERROR\x10\x03\"&\n\x12ServerErrorReceipt\x12\x10\n\x08stanzaID\x18\x01 \x01(\tB&Z$go.mau.fi/whatsmeow/proto/waMmsRetry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waMmsRetry.WAMmsRetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$go.mau.fi/whatsmeow/proto/waMmsRetry'
  _globals['_MEDIARETRYNOTIFICATION']._serialized_start=44
  _globals['_MEDIARETRYNOTIFICATION']._serialized_end=275
  _globals['_MEDIARETRYNOTIFICATION_RESULTTYPE']._serialized_start=194
  _globals['_MEDIARETRYNOTIFICATION_RESULTTYPE']._serialized_end=275
  _globals['_SERVERERRORRECEIPT']._serialized_start=277
  _globals['_SERVERERRORRECEIPT']._serialized_end=315
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ADVEncryptionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ADVEncryptionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ADVEncryptionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    E2EE: _ADVEncryptionType.ValueType  # 0
    HOSTED: _ADVEncryptionType.ValueType  # 1

class ADVEncryptionType(_ADVEncryptionType, metaclass=_ADVEncryptionTypeEnumTypeWrapper): ...

E2EE: ADVEncryptionType.ValueType  # 0
HOSTED: ADVEncryptionType.ValueType  # 1
global___ADVEncryptionType = ADVEncryptionType

@typing.final
class ADVKeyIndexList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAWID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CURRENTINDEX_FIELD_NUMBER: builtins.int
    VALIDINDEXES_FIELD_NUMBER: builtins.int
    ACCOUNTTYPE_FIELD_NUMBER: builtins.int
    rawID: builtins.int
    timestamp: builtins.int
    currentIndex: builtins.int
    accountType: global___ADVEncryptionType.ValueType
    @property
    def validIndexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        rawID: builtins.int | None = ...,
        timestamp: builtins.int | None = ...,
        currentIndex: builtins.int | None = ...,
        validIndexes: collections.abc.Iterable[builtins.int] | None = ...,
        accountType: global___ADVEncryptionType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["accountType", b"accountType", "currentIndex", b"currentIndex", "rawID", b"rawID", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accountType", b"accountType", "currentIndex", b"currentIndex", "rawID", b"rawID", "timestamp", b"timestamp", "validIndexes", b"validIndexes"]) -> None: ...

global___ADVKeyIndexList = ADVKeyIndexList

@typing.final
class ADVSignedKeyIndexList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_FIELD_NUMBER: builtins.int
    ACCOUNTSIGNATURE_FIELD_NUMBER: builtins.int
    ACCOUNTSIGNATUREKEY_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    accountSignature: builtins.bytes
    accountSignatureKey: builtins.bytes
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        accountSignature: builtins.bytes | None = ...,
        accountSignatureKey: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["accountSignature", b"accountSignature", "accountSignatureKey", b"accountSignatureKey", "details", b"details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accountSignature", b"accountSignature", "accountSignatureKey", b"accountSignatureKey", "details", b"details"]) -> None: ...

global___ADVSignedKeyIndexList = ADVSignedKeyIndexList

@typing.final
class ADVDeviceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAWID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    KEYINDEX_FIELD_NUMBER: builtins.int
    ACCOUNTTYPE_FIELD_NUMBER: builtins.int
    DEVICETYPE_FIELD_NUMBER: builtins.int
    rawID: builtins.int
    timestamp: builtins.int
    keyIndex: builtins.int
    accountType: global___ADVEncryptionType.ValueType
    deviceType: global___ADVEncryptionType.ValueType
    def __init__(
        self,
        *,
        rawID: builtins.int | None = ...,
        timestamp: builtins.int | None = ...,
        keyIndex: builtins.int | None = ...,
        accountType: global___ADVEncryptionType.ValueType | None = ...,
        deviceType: global___ADVEncryptionType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["accountType", b"accountType", "deviceType", b"deviceType", "keyIndex", b"keyIndex", "rawID", b"rawID", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accountType", b"accountType", "deviceType", b"deviceType", "keyIndex", b"keyIndex", "rawID", b"rawID", "timestamp", b"timestamp"]) -> None: ...

global___ADVDeviceIdentity = ADVDeviceIdentity

@typing.final
class ADVSignedDeviceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_FIELD_NUMBER: builtins.int
    ACCOUNTSIGNATUREKEY_FIELD_NUMBER: builtins.int
    ACCOUNTSIGNATURE_FIELD_NUMBER: builtins.int
    DEVICESIGNATURE_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    accountSignatureKey: builtins.bytes
    accountSignature: builtins.bytes
    deviceSignature: builtins.bytes
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        accountSignatureKey: builtins.bytes | None = ...,
        accountSignature: builtins.bytes | None = ...,
        deviceSignature: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["accountSignature", b"accountSignature", "accountSignatureKey", b"accountSignatureKey", "details", b"details", "deviceSignature", b"deviceSignature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accountSignature", b"accountSignature", "accountSignatureKey", b"accountSignatureKey", "details", b"details", "deviceSignature", b"deviceSignature"]) -> None: ...

global___ADVSignedDeviceIdentity = ADVSignedDeviceIdentity

@typing.final
class ADVSignedDeviceIdentityHMAC(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_FIELD_NUMBER: builtins.int
    HMAC_FIELD_NUMBER: builtins.int
    ACCOUNTTYPE_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    HMAC: builtins.bytes
    accountType: global___ADVEncryptionType.ValueType
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        HMAC: builtins.bytes | None = ...,
        accountType: global___ADVEncryptionType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["HMAC", b"HMAC", "accountType", b"accountType", "details", b"details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["HMAC", b"HMAC", "accountType", b"accountType", "details", b"details"]) -> None: ...

global___ADVSignedDeviceIdentityHMAC = ADVSignedDeviceIdentityHMAC
